@@ -7,7 +7,7 @@ from typing import Any
 import jsonschema  # type:ignore
 from jsonschema import Draft7Validator, validators
 
-testlib_config_jsonschema_fname = Path(__file__).parent / "schema-wandb-testlib.json"
+testlib_config_jsonschema_fname = Path(__file__).parent / "schema-yea.json"
 with open(testlib_config_jsonschema_fname, "r") as f:
     testlib_config_jsonschema = json.load(f)
 
